data_backdoor: Data generated from a classic backdoor model, where the...

data_backdoorR Documentation

Data generated from a classic backdoor model, where the pre-treatment variable X cause A and Y, and the treatment A cause Y.

Description

Data generated from a classic backdoor model, where the pre-treatment variable X cause A and Y, and the treatment A cause Y.

Usage

data_backdoor

Format

A data frame with 2000 rows and 3 variables: X, A, Y.

X

a variable that follows uniform distribution at the interval of [0,1]

A

a binary treatment

Y

a variable that follows normal distribution

References

https://github.com/annaguo-bios/flexCausal


flexCausal documentation built on March 29, 2026, 5:08 p.m.