data_example_a: Data generated from the simulation model in Figure 4(a) of...

data_example_aR Documentation

Data generated from the simulation model in Figure 4(a) of the paper https://arxiv.org/abs/2409.03962. The model can also be found in Figure (a) of the github repository: https://github.com/annaguo-bios/flexCausal

Description

Data generated from the simulation model in Figure 4(a) of the paper https://arxiv.org/abs/2409.03962. The model can also be found in Figure (a) of the github repository: https://github.com/annaguo-bios/flexCausal

Usage

data_example_a

Format

A data frame with 2000 rows and 7 variables: X, A, U, M=(M.1,M.2), L, Y.

X

a variable that follows uniform distribution at the interval of [0,1]

A

a binary treatment

U

an unmeasured confounder following a normal distribution

M.1

first component of the bivariate mediator M, following a normal distribution

M.2

second component of the bivariate mediator M, following a normal distribution

L

a variable that follows normal distribution

Y

a variable that follows normal distribution

References

https://github.com/annaguo-bios/flexCausal


flexCausal documentation built on March 29, 2026, 5:08 p.m.