| data_example_b | R Documentation |
Data generated from the simulation model in Figure 4(b) of the paper https://arxiv.org/abs/2409.03962. The model can also be found in Figure (b) of the github repository: https://github.com/annaguo-bios/flexCausal
data_example_b
A data frame with 2000 rows and 6 variables: X, A, U1, U2, M=(M.1,M.2), L, Y.
a variable that follows uniform distribution at the interval of [0,1]
a binary treatment
first unmeasured confounder following a normal distribution
second unmeasured confounder following a normal distribution
first component of the bivariate mediator M, following a normal distribution
second component of the bivariate mediator M, following a normal distribution
a variable that follows normal distribution
a variable that follows normal distribution
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.