data_frontdoor: Data generated from a classic front-door model.

data_frontdoorR Documentation

Data generated from a classic front-door model.

Description

Data generated from a front-door model where a pre-treatment variable X and an unmeasured confounder U affect both the treatment A and outcome Y, and the treatment A affects Y through a binary mediator M.

Usage

data_frontdoor

Format

A data frame with 2000 rows and 5 variables:

X

a pre-treatment variable following a uniform distribution on [0, 1]

U

an unmeasured confounder following a normal distribution

A

a binary treatment variable (0/1)

M

a binary mediator variable (0/1)

Y

a continuous outcome variable following a normal distribution

References

https://github.com/annaguo-bios/flexCausal


flexCausal documentation built on March 29, 2026, 5:08 p.m.