f.markov_blanket: Get the Markov blanket of a vertex in a graph.

View source: R/graph-functions.R

f.markov_blanketR Documentation

Get the Markov blanket of a vertex in a graph.

Description

Function to get the Markov blanket of a vertex in a graph object. Markov blanket of a vertex Vi is the union of vertices that is in the district of Vi and their parents set. Mb= union(district(Vi), parents(district(Vi))).

Usage

f.markov_blanket(graph, node)

Arguments

graph

A graph object generated by the make.graph() function.

node

A character string of a vertex for which to extract Markov blanket.

Value

A vector of vertices that is in the Markov blanket of the given vertex.

Examples

graph <- make.graph(vertices=c('A','M','L','Y','X'),
bi_edges=list(c('A','Y')),
di_edges=list(c('X','A'), c('X','M'), c('X','L'),
c('X','Y'), c('M','Y'), c('A','M'), c('A','L'), c('M','L'), c('L','Y')))
f.markov_blanket(graph, 'A')


flexCausal documentation built on March 29, 2026, 5:08 p.m.