is.mb.shielded: Check if a graph is mb-shielded.

View source: R/graph-functions.R

is.mb.shieldedR Documentation

Check if a graph is mb-shielded.

Description

Function to check if a graph is mb-shielded. A graph being mb-shielded means that the graph only implies ordinary equality constraints on the observed data distribution.

Usage

is.mb.shielded(graph)

Arguments

graph

A graph object generated by the make.graph() function.

Value

A logical value indicating whether the graph is mb-shielded.

Examples

graph <- make.graph(vertices=c('A','M','L','Y','X'),
bi_edges=list(c('A','Y')),
di_edges=list(c('X','A'), c('X','M'), c('X','L'),
c('X','Y'), c('M','Y'), c('A','M'), c('A','L'), c('M','L'), c('L','Y')))
is.mb.shielded(graph)

flexCausal documentation built on March 29, 2026, 5:08 p.m.