is.np.saturated: Check if a graph is nonparametrically saturated.

View source: R/graph-functions.R

is.np.saturatedR Documentation

Check if a graph is nonparametrically saturated.

Description

Function to check if a graph is nonparametrically saturated. A graph being nonparametrically saturated means that the graph implies NO equality constraints on the observed data distribution

Usage

is.np.saturated(graph)

Arguments

graph

A graph object generated by the make.graph() function.

Value

A logical value indicating whether the graph is nonparametrically saturated.

Examples

graph <- make.graph(vertices=c('A','M','L','Y','X'),
bi_edges=list(c('A','Y')),
di_edges=list(c('X','A'), c('X','M'), c('X','L'),
c('X','Y'), c('M','Y'), c('A','M'), c('A','L'), c('M','L'), c('L','Y')))
is.np.saturated(graph)


flexCausal documentation built on March 29, 2026, 5:08 p.m.