| data_backdoor | R Documentation |
Data generated from a classic backdoor model, where the pre-treatment variable X cause A and Y, and the treatment A cause Y.
data_backdoor
A data frame with 2000 rows and 3 variables: X, A, Y.
a variable that follows uniform distribution at the interval of [0,1]
a binary treatment
a variable that follows normal distribution
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.