| data_frontdoor | R Documentation |
Data generated from a front-door model where a pre-treatment variable X and an unmeasured confounder U affect both the treatment A and outcome Y, and the treatment A affects Y through a binary mediator M.
data_frontdoor
A data frame with 2000 rows and 5 variables:
a pre-treatment variable following a uniform distribution on [0, 1]
an unmeasured confounder following a normal distribution
a binary treatment variable (0/1)
a binary mediator variable (0/1)
a continuous outcome variable following a normal distribution
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.