View source: R/graph-functions.R
| f.markov_blanket | R Documentation |
Function to get the Markov blanket of a vertex in a graph object. Markov blanket of a vertex Vi is the union of vertices that is in the district of Vi and their parents set. Mb= union(district(Vi), parents(district(Vi))).
f.markov_blanket(graph, node)
graph |
A graph object generated by the |
node |
A character string of a vertex for which to extract Markov blanket. |
A vector of vertices that is in the Markov blanket of the given vertex.
graph <- make.graph(vertices=c('A','M','L','Y','X'),
bi_edges=list(c('A','Y')),
di_edges=list(c('X','A'), c('X','M'), c('X','L'),
c('X','Y'), c('M','Y'), c('A','M'), c('A','L'), c('M','L'), c('L','Y')))
f.markov_blanket(graph, 'A')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.