View source: R/graph-functions.R
| f.markov_pillow | R Documentation |
Function to get the Markov pillow of a vertex in a graph object.
Markov pillow of a vertex Vi is the subset of the Markov blanket of Vi that proceed Vi in the topological ordering of the graph.
Mp= {{Vj in union(district(Vi), parents(district(Vi))): Vj proceed Vi}}.
f.markov_pillow(graph, node, treatment = NULL)
graph |
A graph object generated by the |
node |
A character string of a vertex for which to extract Markov pillow. |
treatment |
A character string specifying the treatment variable in the graph. |
A vector of vertices that is in the Markov pillow of the given vertex.
graph <- make.graph(vertices=c('A','M','L','Y','X'),
bi_edges=list(c('A','Y')),
di_edges=list(c('X','A'), c('X','M'), c('X','L'),
c('X','Y'), c('M','Y'), c('A','M'), c('A','L'), c('M','L'), c('L','Y')))
f.markov_pillow(graph, 'A')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.