View source: R/graph-functions.R
| f.top_order | R Documentation |
Wrapper around f.top_orderMAT() that first builds the adjacency matrix from the graph.
f.top_order(graph, treatment = NULL)
graph |
A graph object generated by the |
treatment |
A character string indicating the treatment variable. If NULL, this function will rank vertices according to their input order in the vertices vector when there are ties. |
A vector of vertices ranked with rank from small to large.
graph <- make.graph(vertices=c('A','M','L','Y','X'),
bi_edges=list(c('A','Y')),
di_edges=list(c('X','A'), c('X','M'), c('X','L'),
c('X','Y'), c('M','Y'), c('A','M'), c('A','L'), c('M','L'), c('L','Y')))
f.top_order(graph)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.