View source: R/graph-functions.R
| is.np.saturated | R Documentation |
Function to check if a graph is nonparametrically saturated. A graph being nonparametrically saturated means that the graph implies NO equality constraints on the observed data distribution
is.np.saturated(graph)
graph |
A graph object generated by the |
A logical value indicating whether the graph is nonparametrically saturated.
graph <- make.graph(vertices=c('A','M','L','Y','X'),
bi_edges=list(c('A','Y')),
di_edges=list(c('X','A'), c('X','M'), c('X','L'),
c('X','Y'), c('M','Y'), c('A','M'), c('A','L'), c('M','L'), c('L','Y')))
is.np.saturated(graph)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.