View source: R/graph-functions.R
| is.p.fix | R Documentation |
Function to check if a treatment variable is primal fixable in a graph object. If the treatment is primal fixable, then the average causal effect of the treatment on any choice of the outcome in the given graph is always identified.
is.p.fix(graph, treatment)
graph |
A graph object generated by the |
treatment |
A character string specifying the treatment variable in the graph. |
A logical value indicating whether the treatment is primal fixable.
graph <- make.graph(vertices=c('A','M','L','Y','X'),
bi_edges=list(c('A','Y')),
di_edges=list(c('X','A'), c('X','M'), c('X','L'),
c('X','Y'), c('M','Y'), c('A','M'), c('A','L'), c('M','L'), c('L','Y')))
is.p.fix(graph, 'A')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.